@@ -1,6 +1,8 @@
+import inspect
 import typing
 from dataclasses import dataclass
-from numbers import Number as ParentNumber
+
+T = typing.TypeVar("T")
 
 
 @dataclass
@@ -15,7 +17,7 @@ class MapBefore:
 
 
 @dataclass
-class Pred:
+class Predicate:
     pred: typing.Optional[typing.Callable[[], bool]] = None
 
     def __eq__(self, other):
@@ -27,18 +29,33 @@ class Pred:
         return True
 
 
+@dataclass
+class Equals(typing.Generic[T]):
+    equals: typing.Optional[T] = None
+
+    def __eq__(self, other):
+        if self.equals is not None and not other == self.equals:
+            return False
+        return True
+
+
 @dataclass
 class Instance:
     type: typing.Optional[typing.Type] = None
-    instanceof: typing.Optional[typing.Type] = None
+    instance_of: typing.Optional[typing.Type] = None
 
     def __eq__(self, other):
         # TODO check
-        if not (isinstance(other, ParentNumber) or isinstance(other, typing.Collection)):
+        if (
+            inspect.ismodule(other)
+            or inspect.isclass(other)
+            or inspect.isfunction(other)
+            or inspect.ismethod(other)
+        ):
             return False
         if self.type and type(other) != self.type:
             return False
-        if self.instanceof and not isinstance(other, self.instanceof):
+        if self.instance_of and not isinstance(other, self.instance_of):
             return False
         return True
 
@@ -46,13 +63,13 @@ class Instance:
 @dataclass
 class Class:
     type: typing.Optional[typing.Type] = None
-    subclassof: typing.Optional[typing.Type] = None
+    subclass_of: typing.Optional[typing.Type] = None
 
     def __eq__(self, other):
         if not type(other) == type:
             return False
         if self.type and other != self.type:
             return False
-        if self.subclassof and not issubclass(other, self.subclassof):
+        if self.subclass_of and not issubclass(other, self.subclass_of):
             return False
         return True
